% Auto-generated chapter 28 for tirmidhi
% Hadiths in this chapter: 54

\hadithdefcmd{tirmidhi}{2036}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قال حَدَّثَنَا إِسْحَاقُ بْنُ مُحَمَّدٍ الْفَرْوِيُّ، قال حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ قَتَادَةَ بْنِ النُّعْمَانِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَحَبَّ اللَّهُ عَبْدًا حَمَاهُ الدُّنْيَا كَمَا يَظَلُّ أَحَدُكُمْ يَحْمِي سَقِيمَهُ الْمَاءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ صُهَيْبٍ وَأُمِّ الْمُنْذِرِ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ مَحْمُودِ بْنِ لَبِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قال أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ عَنْ قَتَادَةَ بْنِ النُّعْمَانِ ‏.‏ قَالَ أَبُو عِيسَى وَقَتَادَةُ بْنُ النُّعْمَانِ الظَّفَرِيُّ هُوَ أَخُو أَبِي سَعِيدٍ الْخُدْرِيِّ لأُمِّهِ وَمَحْمُودُ بْنُ لَبِيدٍ قَدْ أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم وَرَآهُ وَهُوَ غُلاَمٌ صَغِيرٌ ‏.‏\hadithno{2036}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Qatadah bin An-Nu'man narrated that the Messenger of Allah (s.a.w) said:"When Allah loves a slave, He prevents him from the world, just as one of you prevents his sick from water." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2037}{حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، قال حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، قال حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ عُثْمَانَ بْنِ عَبْدِ الرَّحْمَنِ التَّيْمِيِّ، عَنْ يَعْقُوبَ بْنِ أَبِي يَعْقُوبَ، عَنْ أُمِّ الْمُنْذِرِ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعَهُ عَلِيٌّ وَلَنَا دَوَالٍ مُعَلَّقَةٌ قَالَتْ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْكُلُ وَعَلِيٌّ مَعَهُ يَأْكُلُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعَلِيٍّ ‏"‏ مَهْ مَهْ يَا عَلِيُّ فَإِنَّكَ نَاقِهٌ ‏"‏ ‏.‏ قَالَ فَجَلَسَ عَلِيٌّ وَالنَّبِيُّ صلى الله عليه وسلم يَأْكُلُ ‏.‏ قَالَتْ فَجَعَلْتُ لَهُمْ سِلْقًا وَشَعِيرًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا عَلِيُّ مِنْ هَذَا فَأَصِبْ فَإِنَّهُ أَوْفَقُ لَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ فُلَيْحٍ ‏.‏ وَيُرْوَى عَنْ فُلَيْحٍ عَنْ أَيُّوبَ بْنِ عَبْدِ الرَّحْمَنِ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قال حَدَّثَنَا أَبُو عَامِرٍ، وَأَبُو دَاوُدَ قَالاَ حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ أَيُّوبَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ يَعْقُوبَ، عَنْ أُمِّ الْمُنْذِرِ الأَنْصَارِيَّةِ، فِي حَدِيثِهِ قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ نَحْوَ حَدِيثِ يُونُسَ بْنِ مُحَمَّدٍ إِلاَّ أَنَّهُ قَالَ ‏"‏ أَنْفَعُ لَكَ ‏"‏ ‏.‏ وَقَالَ مُحَمَّدُ بْنُ بَشَّارٍ وَحَدَّثَنِيهِ أَيُّوبُ بْنُ عَبْدِ الرَّحْمَنِ ‏.‏ هَذَا حَدِيثٌ جَيِّدٌ غَرِيبٌ ‏.‏\hadithno{2037}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umm Al-Mundhir said:"The Messenger of Allah (ﷺ) entered upon me, while `Ali was with him, and we had a cluster of unripe dates hanging." She said: "The Messenger of Allah (ﷺ) began eating, and `Ali ate with him. The Messenger of Allah (ﷺ) said to `Ali: 'Stop, stop, for you are still recovering.' So `Ali sat and the Prophet (ﷺ) ate." She said: "I made some chard and barley for them, so the Prophet (ﷺ) said: 'O `Ali eat from this, for indeed it will be more suitable for you." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2038}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الْعَقَدِيُّ، قال حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ أُسَامَةَ بْنِ شَرِيكٍ، قَالَ قَالَتِ الأَعْرَابُ يَا رَسُولَ اللَّهِ أَلاَ نَتَدَاوَى قَالَ ‏"‏ نَعَمْ يَا عِبَادَ اللَّهِ تَدَاوَوْا فَإِنَّ اللَّهَ لَمْ يَضَعْ دَاءً إِلاَّ وَضَعَ لَهُ شِفَاءً أَوْ قَالَ دَوَاءً إِلاَّ دَاءً وَاحِدًا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا هُوَ قَالَ ‏"‏ الْهَرَمُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ وَأَبِي خُزَامَةَ عَنْ أَبِيهِ وَابْنِ عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2038}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Usamah bin Sharik said:"Some Bedouins asked: 'O Messenger of Allah (s.a.w) shall we treat (our ill)?' He said: 'Yes, O worshipers of Allah! Use remedies. For indeed Allah did not make a disease but He made a cure for it' - or - 'a remedy. Except for one disease.' They said: 'O Messenger of Allah (s.a.w)! What is it?' He said: 'Old age}}
\hadithdefcmd{tirmidhi}{2039}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قال أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ،قال حَدَّثَنَا مُحَمَّدُ بْنُ السَّائِبِ بْنِ بَرَكَةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَخَذَ أَهْلَهُ الْوَعْكُ أَمَرَ بِالْحَسَاءِ فَصُنِعَ ثُمَّ أَمَرَهُمْ فَحَسَوْا مِنْهُ وَكَانَ يَقُولُ ‏ "‏ إِنَّهُ لَيَرْتُو فُؤَادَ الْحَزِينِ وَيَسْرُو عَنْ فُؤَادِ السَّقِيمِ كَمَا تَسْرُو إِحْدَاكُنَّ الْوَسَخَ بِالْمَاءِ عَنْ وَجْهِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ ابْنُ الْمُبَارَكِ عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا بِذَلِكَ الْحُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو إِسْحَاقَ الطَّالْقَانِيُّ، عَنِ ابْنِ الْمُبَارَكِ، عن يونس، عن الزهري بمعناه\hadithno{2039}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah narrated:"Whenever one of the wives of the Messenger of Allah (s.a.w) became (feverishly) ill, he would order that some broth be prepared. Then he would tell them to take some of the broth. And he would say: 'It firms the heart of the grieved, and it rids the worries from the heart of the ill just as one of you removes dirt from her face with water." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2040}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا بَكْرُ بْنُ يُونُسَ بْنِ بُكَيْرٍ، عَنْ مُوسَى بْنِ عَلِيٍّ، عَنْ أَبِيهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُكْرِهُوا مَرْضَاكُمْ عَلَى الطَّعَامِ فَإِنَّ اللَّهَ تبارك و تعالى يُطْعِمُهُمْ وَيَسْقِيهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2040}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Uqbah bin Amir Al-Juhani narrated that the Messenger of Allah (s.a.w) said:"Do not force your sick to eat, for indeed Allah, Blessed and Most High, provides them food and drink."(Dai'f)}}
\hadithdefcmd{tirmidhi}{2041}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ عَلَيْكُمْ بِهَذِهِ الْحَبَّةِ السَّوْدَاءِ فَإِنَّ فِيهَا شِفَاءً مِنْ كُلِّ دَاءٍ إِلاَّ السَّامَ ‏"‏ ‏.‏ وَالسَّامُ الْمَوْتُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَابْنِ عُمَرَ وَعَائِشَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْحَبَّةُ السَّوْدَاءُ هِيَ الشُّونِيزُ ‏.‏\hadithno{2041}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Use this black seed. For indeed it contains a cure for every disease except As-Sam" And As-Sam is death}}
\hadithdefcmd{tirmidhi}{2042}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، قَالَ أَخْبَرَنَا حُمَيْدٌ، وَثَابِتٌ، وَقَتَادَةُ، عَنْ أَنَسٍ، أَنَّ نَاسًا، مِنْ عُرَيْنَةَ قَدِمُوا الْمَدِينَةَ فَاجْتَوَوْهَا فَبَعَثَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي إِبِلِ الصَّدَقَةِ وَقَالَ ‏ "‏ اشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2042}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas narrated "Some people from Urainah arrived in Al-Madinah, and they were uncomfortable (with the climate). So the Messenger of Allah (s.a.w) sent them some camels from charity. He told them:"Drink from their milk and Urine}}
\hadithdefcmd{tirmidhi}{2043}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قال حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أُرَاهُ رَفَعَهُ قَالَ ‏ "‏ مَنْ قَتَلَ نَفْسَهُ بِحَدِيدَةٍ جَاءَ يَوْمَ الْقِيَامَةِ وَحَدِيدَتُهُ فِي يَدِهِ يَتَوَجَّأُ بِهَا فِي بَطْنِهِ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا أَبَدًا وَمَنْ قَتَلَ نَفْسَهُ بِسُمٍّ فَسُمُّهُ فِي يَدِهِ يَتَحَسَّاهُ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا أَبَدًا ‏"‏ ‏.‏\hadithno{2043}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated (from the Messenger of Allah (s.a.w)):"Whoever kills himself with (an instrument of)iron, he will come on the Day Of Judgment with his iron in his hand, to continually stab himself in his stomach with it, in the fire of Jahannam, dwelling in that state eternally. And whoever kills himself with poison, then his poison will be in his hand, to continually take it in the Fire of Jahannam, dwelling in that state eternally}}
\hadithdefcmd{tirmidhi}{2044}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قال حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ قَتَلَ نَفْسَهُ بِحَدِيدَةٍ فَحَدِيدَتُهُ فِي يَدِهِ يَتَوَجَّأُ بِهَا فِي بَطْنِهِ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا وَمَنْ قَتَلَ نَفْسَهُ بِسُمٍّ فَسُمُّهُ فِي يَدِهِ يَتَحَسَّاهُ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا وَمَنْ تَرَدَّى مِنْ جَبَلٍ فَقَتَلَ نَفْسَهُ فَهُوَ يَتَرَدَّى فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قال حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ شُعْبَةَ عَنِ الأَعْمَشِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ وَهُوَ أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏ هَكَذَا رَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى مُحَمَّدُ بْنُ عَجْلاَنَ عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ قَتَلَ نَفْسَهُ بِسُمٍّ عُذِّبَ فِي نَارِ جَهَنَّمَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا ‏.‏ وَهَكَذَا رَوَاهُ أَبُو الزِّنَادِ عَنِ الأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهَذَا أَصَحُّ لأَنَّ الرِّوَايَاتِ إِنَّمَا تَجِيءُ بِأَنَّ أَهْلَ التَّوْحِيدِ يُعَذَّبُونَ فِي النَّارِ ثُمَّ يُخْرَجُونَ مِنْهَا وَلَمْ يُذْكَرْ أَنَّهُمْ يُخَلَّدُونَ فِيهَا ‏.‏\hadithno{2044}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated (that the the Messenger of Allah (s.a.w)) said:"Whoever kills himself with (an instrument of)iron, his iron will be in his hand, to continually stab himself in his stomach with it, in the fire of Jahannam, dwelling in that state eternally. And whoever kills himself with poison, then his poison will be in his hand, to continually take it in the Fire of Jahannam, dwelling in that state eternally. And whoever throws himself from a mountain to kill himself, then he will be continually throwing himself in the Fire of Jahannam, dwelling in that state eternally." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2045}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، قال أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، عَنْ مُجَاهِدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدَّوَاءِ الْخَبِيثِ ‏.‏ قَالَ أَبُو عِيسَى يَعْنِي السُّمَّ ‏.‏\hadithno{2045}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah (s.a.w) forbade from cures that are Khabith." [Abu 'Elsa said:] Meaning poison}}
\hadithdefcmd{tirmidhi}{2046}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قال حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، أَنَّهُ سَمِعَ عَلْقَمَةَ بْنَ وَائِلٍ، عَنْ أَبِيهِ، أَنَّهُ شَهِدَ النَّبِيَّ صلى الله عليه وسلم وَسَأَلَهُ سُوَيْدُ بْنُ طَارِقٍ أَوْ طَارِقُ بْنُ سُوَيْدٍ عَنِ الْخَمْرِ فَنَهَاهُ عَنْهُ فَقَالَ إِنَّنَا نَتَدَاوَى بِهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّهَا لَيْسَتْ بِدَوَاءٍ وَلَكِنَّهَا دَاءٌ ‏"‏ ‏.‏ حَدَّثَنَا مَحْمُودٌ، قال حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، وَشَبَابَةُ، عَنْ شُعْبَةَ، بِمِثْلِهِ ‏.‏ قَالَ مَحْمُودٌ قَالَ النَّضْرُ طَارِقُ بْنُ سُوَيْدٍ وَقَالَ شَبَابَةُ سُوَيْدُ بْنُ طَارِقٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ\hadithno{2046}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Simak narrated that he heard 'Alqamah bin Wa'il narrate from his father, that he witnessed the Prophet (s.a.w) being asked by Suwaid bin Tariq -or Tariq bin Suwaid- about Khamr, and he forbade it. So he said:"We use it as a treatment." So the Messenger of Allah (S.A.W) said: "It is certainly not a treatment, rather, it is a disease." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2047}{حَدَّثَنَا مُحَمَّدُ بْنُ مَدُّويَهْ، قال حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ حَمَّادٍ الشُّعَيْثِيُّ، قال حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ خَيْرَ مَا تَدَاوَيْتُمْ بِهِ السَّعُوطُ وَاللَّدُودُ وَالْحِجَامَةُ وَالْمَشِيُّ ‏"‏ ‏.‏ فَلَمَّا اشْتَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم لَدَّهُ أَصْحَابُهُ فَلَمَّا فَرَغُوا قَالَ ‏"‏ لُدُّوهُمْ ‏"‏ ‏.‏ قَالَ فَلُدُّوا كُلُّهُمْ غَيْرَ الْعَبَّاسِ ‏.‏\hadithno{2047}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (s.a.w) said:"Indeed the best of what you treat is As-Sa'ut, Al-Ladud, cupping and laxatives.' So when the Messenger of Allah (S.A.W) was suffering his companions treated him with Al-Ladud, and when they were finished he said: 'Treat them with Al-Ladud.' So all of them except Al-Abbas were treated with Al-Ladud."(Daif)}}
\hadithdefcmd{tirmidhi}{2048}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قال حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قال حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ خَيْرَ مَا تَدَاوَيْتُمْ بِهِ اللَّدُودُ وَالسَّعُوطُ وَالْحِجَامَةُ وَالْمَشِيُّ وَخَيْرُ مَا اكْتَحَلْتُمْ بِهِ الإِثْمِدُ فَإِنَّهُ يَجْلُو الْبَصَرَ وَيُنْبِتُ الشَّعْرَ ‏"‏ ‏.‏ قَالَ وَكَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مُكْحُلَةٌ يَكْتَحِلُ بِهَا عِنْدَ النَّوْمِ ثَلاَثًا فِي كُلِّ عَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَهُوَ حَدِيثُ عَبَّادِ بْنِ مَنْصُورٍ ‏.‏\hadithno{2048}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (s.a.w) said:"Indeed the best of what you treat is As-Sa'ut, Al-Ladud, cupping and laxatives.' And the best of what you use for Kuhl is Ithmid, for it clears the vision and grows the hair (eye-lashes)." And he said:" The Messenger of Allah (s.a.w) had a Kuhl holder with which he would apply Kuhl before sleeping three in each eye}}
\hadithdefcmd{tirmidhi}{2049}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْكَىِّ ‏.‏ قَالَ فَابْتُلِينَا فَاكْتَوَيْنَا فَمَا أَفْلَحْنَا وَلاَ أَنْجَحْنَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ, قَالَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ نُهِينَا عَنِ الْكَىِّ، ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ، وَعُقْبَةَ بْنِ عَامِرٍ، وَابْنِ، عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2049}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Imran bin Husain narrated that the Messenger of Allah (s.a.w) prohibited cauterization. He said:"We were tested (with severe medical condition) so we were cauterized, but we did not have good results, nor was it successful for us." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2050}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قال حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قال أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَوَى أَسْعَدَ بْنَ زُرَارَةَ مِنَ الشَّوْكَةِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أُبَىٍّ وَجَابِرٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2050}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated:"The Prophet (S.A.W) cauterized As'ad bin Zurarah for Shawkah}}
\hadithdefcmd{tirmidhi}{2051}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا هَمَّامٌ، وَجَرِيرُ بْنُ حَازِمٍ، قَالاَ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَحْتَجِمُ فِي الأَخْدَعَيْنِ وَالْكَاهِلِ وَكَانَ يَحْتَجِمُ لِسَبْعَ عَشْرَةَ وَتِسْعَ عَشْرَةَ وَإِحْدَى وَعِشْرِينَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَمَعْقِلِ بْنِ يَسَارٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صحيح ‏.‏\hadithno{2051}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated:"The Prophet (S.A.W) would get cupped in his jugular veins and his upper back. And he would get cupped on the seventeenth (of the month), (or) the nineteenth, and (or) the twenty first}}
\hadithdefcmd{tirmidhi}{2052}{حَدَّثَنَا أَحْمَدُ بْنُ بُدَيْلِ بْنِ قُرَيْشٍ الْيَامِيُّ الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، هُوَ ابْنُ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ عَنْ أَبِيهِ، عَنِ ابْنِ مَسْعُودٍ، قَالَ حَدَّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لَيْلَةَ، أُسْرِيَ بِهِ أَنَّهُ لَمْ يَمُرَّ عَلَى مَلإٍ مِنَ الْمَلاَئِكَةِ إِلاَّ أَمَرُوهُ أَنْ مُرْ أُمَّتَكَ بِالْحِجَامَةِ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ مَسْعُودٍ ‏.‏\hadithno{2052}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Mas'ud said:"The Messenger of Allah (S.A.W) narrated about the Night of Isra', saying that he did not pass an assembly of angels except that they ordered him: 'Order cupping among your Ummah}}
\hadithdefcmd{tirmidhi}{2053}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، قَالَ سَمِعْتُ عِكْرِمَةَ، يَقُولُ كَانَ لاِبْنِ عَبَّاسٍ غِلْمَةٌ ثَلاَثَةٌ حَجَّامُونَ فَكَانَ اثْنَانِ مِنْهُمْ يُغِلاَّنِ عَلَيْهِ وَعَلَى أَهْلِهِ وَوَاحِدٌ يَحْجُمُهُ وَيَحْجُمُ أَهْلَهُ ‏.‏ قَالَ وَقَالَ ابْنُ عَبَّاسٍ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ نِعْمَ الْعَبْدُ الْحَجَّامُ يُذْهِبُ الدَّمَ وَيُخِفُّ الصُّلْبَ وَيَجْلُو عَنِ الْبَصَرِ ‏"‏ ‏.‏ وَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ عُرِجَ بِهِ مَا مَرَّ عَلَى مَلإٍ مِنَ الْمَلاَئِكَةِ إِلاَّ قَالُوا عَلَيْكَ بِالْحِجَامَةِ ‏.‏ وَقَالَ ‏"‏ إِنَّ خَيْرَ مَا تَحْتَجِمُونَ فِيهِ يَوْمَ سَبْعَ عَشَرَةَ وَيَوْمَ تِسْعَ عَشَرَةَ وَيَوْمَ إِحْدَى وَعِشْرِينَ ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِنَّ خَيْرَ مَا تَدَاوَيْتُمْ بِهِ السَّعُوطُ وَاللَّدُودُ وَالْحِجَامَةُ وَالْمَشِيُّ ‏"‏ ‏.‏ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَدَّهُ الْعَبَّاسُ وَأَصْحَابُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ لَدَّنِي فَكُلُّهُمْ أَمْسَكُوا فَقَالَ ‏"‏ لاَ يَبْقَى أَحَدٌ مِمَّنْ فِي الْبَيْتِ إِلاَّ لُدَّ ‏"‏ ‏.‏ غَيْرَ عَمِّهِ الْعَبَّاسِ قَالَ عَبْدٌ قَالَ النَّضْرُ اللَّدُودُ الْوَجُورُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبَّادِ بْنِ مَنْصُورٍ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏\hadithno{2053}\hadithgrade{Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Abbad bin Mansur narrated from 'Ikrimah who said:"Ibn 'Abbas had three boys who were cuppers. He would use the proceeds from two of them for himself and his family, and one of them would cup him and his family." He said: " Ibn 'Abbas said: 'The Prophet (S.A.W) said: 'How excellent is the slave who cups, letting the blood, relieving the back, and clearing the vision." And he said: "Indeed the best for you to cup on are the seventeenth, the nineteenth, and the twenty-first." And he said: "Indeed the best of what you treat is As-Sa'ut, Al-Ladud, cupping and laxatives." And indeed, The Messenger of Allah (S.A.W) was given medicine by Al-Abbas and his companions. So the The Messenger of Allah (S.A.W) said: "Who gave me this medicine?" All of them were silent, so he said that there shall not remain anyone in the house but he should be treated with Ladud except for his uncle Al-Abbas.'" An-Nadr said: "Al-Ladud is Al-Wajur}}
\hadithdefcmd{tirmidhi}{2054}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قال حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ الْخَيَّاطُ، قال حَدَّثَنَا فَائِدٌ، مَوْلًى لآلِ أَبِي رَافِعٍ عَنْ عَلِيِّ بْنِ عُبَيْدِ اللَّهِ، عَنْ جَدَّتِهِ، سَلْمَى وَكَانَتْ تَخْدُمُ النَّبِيَّ صلى الله عليه وسلم قَالَتْ مَا كَانَ يَكُونُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم قُرْحَةٌ وَلاَ نَكْبَةٌ إِلاَّ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَضَعَ عَلَيْهَا الْحِنَّاءَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ فَائِدٍ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ فَائِدٍ فَقَالَ عَنْ عُبَيْدِ اللَّهِ بْنِ عَلِيٍّ عَنْ جَدَّتِهِ سَلْمَى وَعُبَيْدُ اللَّهِ بْنُ عَلِيٍّ أَصَحُّ وَيُقَالُ سُلْمَى ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قال حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ فَائِدٍ، مَوْلَى عُبَيْدِ اللَّهِ بْنِ عَلِيٍّ عَنْ مَوْلاَهُ، عُبَيْدِ اللَّهِ بْنِ عَلِيٍّ عَنْ جَدَّتِهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏\hadithno{2054}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ali bin 'Ubaidullah narrated that his grandmother [Salma] - who used to serve the The Prophet (S.A.W) said:"There was no wound nor cut on the Messenger of Allah (S.A.W) but he would order me to put Hinna on it." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2055}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ عَقَّارِ بْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اكْتَوَى أَوِ اسْتَرْقَى فَقَدْ بَرِئَ مِنَ التَّوَكُّلِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَابْنِ عَبَّاسٍ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2055}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aqqar bin Al-Mughirah bin Shu'bah narrated from his father who said that the Messenger of Allah (s.a.w) said:"Whoever seeks treatment by cauterization, or with Ruqyah, then he has absolved himself of At-Tawakkul (reliance upon Allah)}}
\hadithdefcmd{tirmidhi}{2056}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ، قال حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ سُفْيَانَ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي الرُّقْيَةِ مِنَ الْحُمَةِ وَالْعَيْنِ وَالنَّمْلَةِ ‏.‏ حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قال حَدَّثَنَا يَحْيَى بْنُ آدَمَ، وَأَبُو نُعَيْمٍ قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي الرُّقْيَةِ مِنَ الْحُمَةِ وَالنَّمْلَةِ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا عِنْدِي أَصَحُّ مِنْ حَدِيثِ مُعَاوِيَةَ بْنِ هِشَامٍ عَنْ سُفْيَانَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَعِمْرَانَ بْنِ حُصَيْنٍ وَجَابِرٍ وَعَائِشَةَ وَطَلْقِ بْنِ عَلِيٍّ وَعَمْرِو بْنِ حَزْمٍ وَأَبِي خُزَامَةَ عَنْ أَبِيهِ ‏.‏\hadithno{2056}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated that :the Messenger of Allah (s.a.w) permitted Ruqyah for the scorpion sting, the(evil) eye, and An-Namlah. Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2057}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ رُقْيَةَ إِلاَّ مِنْ عَيْنٍ أَوْ حُمَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ حُصَيْنٍ عَنِ الشَّعْبِيِّ عَنْ بُرَيْدَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2057}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Imran bin Husain narrated that the Messenger of Allah (S.A.W) said:"No Ruqyah except for the (evil) eye and the scorpion sting}}
\hadithdefcmd{tirmidhi}{2058}{حَدَّثَنَا هِشَامُ بْنُ يُونُسَ الْكُوفِيُّ، قَالَ حَدَّثَنَا الْقَاسِمُ بْنُ مَالِكٍ الْمُزَنِيُّ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَعَوَّذُ مِنَ الْجَانِّ وَعَيْنِ الإِنْسَانِ حَتَّى نَزَلَتِ الْمُعَوِّذَتَانِ فَلَمَّا نَزَلَتَا أَخَذَ بِهِمَا وَتَرَكَ مَا سِوَاهُمَا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2058}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated:"The Messenger of Allah(S.A.W) would seek refuge from the jinn and the (evil) eye of humans, until Al-Mu'awwidhatain were revealed. So when they were revealed he used them and left other than them}}
\hadithdefcmd{tirmidhi}{2059}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عُرْوَةَ، وَهُوَ أَبُو حَاتِمِ بْنُ عَامِرٍ عَنْ عُبَيْدِ بْنِ رِفَاعَةَ الزُّرَقِيِّ، أَنَّ أَسْمَاءَ بِنْتَ عُمَيْسٍ، قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ وَلَدَ جَعْفَرٍ تُسْرِعُ إِلَيْهِمُ الْعَيْنُ أَفَأَسْتَرْقِي لَهُمْ فَقَالَ ‏ "‏ نَعَمْ فَإِنَّهُ لَوْ كَانَ شَيْءٌ سَابَقَ الْقَدَرَ لَسَبَقَتْهُ الْعَيْنُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَبُرَيْدَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا، عَنْ أَيُّوبَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عُرْوَةَ بْنِ عَامِرٍ، عَنْ عُبَيْدِ بْنِ رِفَاعَةَ، عَنْ أَسْمَاءَ بِنْتِ عُمَيْسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا بِذَلِكَ الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، بِهَذَا ‏.‏\hadithno{2059}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Asma' bint 'Umaish said:" I said: 'O Messenger of Allah (S.A.W)! Some of Ja'far's children have suffered from an accelerated case of the inflammation of the eye, so should I have them treated with Ruqyah?' He said: 'Yes,for indeed if there was anything that could overcome the Decree, then the evil eye would overcome it}}
\hadithdefcmd{tirmidhi}{2060}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قال حَدَّثَنَا عَبْدُ الرَّزَّاقِ، وَيَعْلَى، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَوِّذُ الْحَسَنَ وَالْحُسَيْنَ يَقُولُ ‏"‏ أُعِيذُكُمَا بِكَلِمَاتِ اللَّهِ التَّامَّةِ مِنْ كُلِّ شَيْطَانٍ وَهَامَّةٍ وَمِنْ كُلِّ عَيْنٍ لاَمَّةٍ ‏"‏ ‏.‏ وَيَقُولُ ‏"‏ هَكَذَا كَانَ إِبْرَاهِيمُ يُعَوِّذُ إِسْحَاقَ وَإِسْمَاعِيلَ عَلَيْهِمُ السَّلاَمُ ‏"‏ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ وَعَبْدُ الرَّزَّاقِ عَنْ سُفْيَانَ عَنْ مَنْصُورٍ نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2060}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (S.A.W) used to seek refuge for Al-Hasan and Al-Husain saying:""U'idhukuma bikalimatillahi-tammati,min kulli shaitanin wa hammatin, wa minkulli'ainin lammah (I seek refuge for the two of you in the Perfect Words of Allah, from every devil and every poisonous pest, and from every harmful eye)." And he would say: "It is with this that Ibrahim would seek refuge for Ishhaq and Ismail [peace be upon them]." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2061}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ, قال حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ أَبُو غَسَّانَ الْعَنْبَرِيُّ، قال حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنِي حَيَّةُ بْنُ حَابِسٍ التَّمِيمِيُّ، حَدَّثَنِي أَبِي أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ شَىْءَ فِي الْهَامِ وَالْعَيْنُ حَقٌّ ‏"‏ ‏.‏\hadithno{2061}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Hayyah bin Habis At-Tamimi narrated:My father narrated that he heard the Messenger of Allah (s.a.w) saying: "There is nothing to Al-Ham, and the eye is real}}
\hadithdefcmd{tirmidhi}{2062}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ بْنِ خِرَاشٍ الْبَغْدَادِيُّ، قال حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ الْحَضْرَمِيُّ، قال حَدَّثَنَا وُهَيْبٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَ شَيْءٌ سَابَقَ الْقَدَرَ لَسَبَقَتْهُ الْعَيْنُ وَإِذَا اسْتُغْسِلْتُمْ فَاغْسِلُوا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَحَدِيثُ حَيَّةَ بْنِ حَابِسٍ حَدِيثٌ غَرِيبٌ ‏.‏ وَرَوَى شَيْبَانُ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ حَيَّةَ بْنِ حَابِسٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَعَلِيُّ بْنُ الْمُبَارَكِ وَحَرْبُ بْنُ شَدَّادٍ لاَ يَذْكُرَانِ فِيهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2062}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (s.a.w) said:"If there was anything that could overcome the Decree then the (evil) eye would overcome it, and when you are requested to wash (due to it) then wash}}
\hadithdefcmd{tirmidhi}{2063}{حَدَّثَنَا هَنَّادٌ، قال حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ جَعْفَرِ بْنِ إِيَاسٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَرِيَّةٍ فَنَزَلْنَا بِقَوْمٍ فَسَأَلْنَاهُمُ الْقِرَى فَلَمْ يَقْرُونَا فَلُدِغَ سَيِّدُهُمْ فَأَتَوْنَا فَقَالُوا هَلْ فِيكُمْ مَنْ يَرْقِي مِنَ الْعَقْرَبِ قُلْتُ نَعَمْ أَنَا وَلَكِنْ لاَ أَرْقِيهِ حَتَّى تُعْطُونَا غَنَمًا ‏.‏ قَالُوا فَإِنَّا نُعْطِيكُمْ ثَلاَثِينَ شَاةً ‏.‏ فَقَبِلْنَا فَقَرَأْتُ عَلَيْهِ ‏(‏الْحَمْدُ لِلَّهِ ‏)‏ سَبْعَ مَرَّاتٍ فَبَرَأَ وَقَبَضْنَا الْغَنَمَ ‏.‏ قَالَ فَعَرَضَ فِي أَنْفُسِنَا مِنْهَا شَيْءٌ فَقُلْنَا لاَ تَعْجَلُوا حَتَّى تَأْتُوا رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فَلَمَّا قَدِمْنَا عَلَيْهِ ذَكَرْتُ لَهُ الَّذِي صَنَعْتُ قَالَ ‏"‏ وَمَا عَلِمْتَ أَنَّهَا رُقْيَةٌ اقْبِضُوا الْغَنَمَ وَاضْرِبُوا لِي مَعَكُمْ بِسَهْمٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو نَضْرَةَ اسْمُهُ الْمُنْذِرُ بْنُ مَالِكِ بْنِ قُطَعَةَ ‏.‏ وَرَخَّصَ الشَّافِعِيُّ لِلْمُعَلِّمِ أَنْ يَأْخُذَ عَلَى تَعْلِيمِ الْقُرْآنِ أَجْرًا وَيَرَى لَهُ أَنْ يَشْتَرِطَ عَلَى ذَلِكَ ‏.‏ وَاحْتَجَّ بِهَذَا الْحَدِيثِ ‏.‏ وَرَوَى شُعْبَةُ وَأَبُو عَوَانَةَ وَغَيْرُ وَاحِدٍ عَنْ أَبِي بِشْرٍ هَذَا الْحَدِيثَ عَنْ أَبِي الْمُتَوَكِّلِ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2063}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed narrated:"The Messenger of Allah (s.a.w) dispatched us on a military expedition. We camped with some people and asked them to entertain us but they did not entertain us. Their leader was stung so they came to us saying: 'Is there anyone among you who can treat a scorpion sting with Ruqyah?' I said: 'Yes I can. But I will not do any Ruqyah until you give us some sheep.' They said: 'Then we shall give you thirty sheep.' We accepted that,and I recited Al-Hamda [Lillah] seven times. He became better and we took the sheep." He said: "We became concerned about that being permissible and said: 'Do not be hasty until we reach the Messenger of Allah (S.A.W)." He said: "When we arrived with him I mentioned what I did to him. He(S.A.W)said: 'How did you know that it was a Ruqyah? Take the sheep, and assign me a share among you}}
\hadithdefcmd{tirmidhi}{2064}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنِي عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو بِشْرٍ، قَالَ سَمِعْتُ أَبَا الْمُتَوَكِّلِ، يُحَدِّثُ عَنْ أَبِي سَعِيدٍ، أَنَّ نَاسًا، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مَرُّوا بِحَىٍّ مِنَ الْعَرَبِ فَلَمْ يَقْرُوهُمْ وَلَمْ يُضَيِّفُوهُمْ فَاشْتَكَى سَيِّدُهُمْ فَأَتَوْنَا فَقَالُوا هَلْ عِنْدَكُمْ دَوَاءٌ قُلْنَا نَعَمْ وَلَكِنْ لَمْ تَقْرُونَا وَلَمْ تُضَيِّفُونَا فَلاَ نَفْعَلُ حَتَّى تَجْعَلُوا لَنَا جُعْلاً ‏.‏ فَجَعَلُوا عَلَى ذَلِكَ قَطِيعًا مِنَ الْغَنَمِ ‏.‏ قَالَ فَجَعَلَ رَجُلٌ مِنَّا يَقْرَأُ عَلَيْهِ بِفَاتِحَةِ الْكِتَابِ فَبَرَأَ فَلَمَّا أَتَيْنَا النَّبِيَّ صلى الله عليه وسلم ذَكَرْنَا ذَلِكَ لَهُ قَالَ ‏"‏ وَمَا يُدْرِيكَ أَنَّهَا رُقْيَةٌ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ نَهْيًا مِنْهُ وَقَالَ ‏"‏ كُلُوا وَاضْرِبُوا لِي مَعَكُمْ بِسَهْمٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ وَهَذَا أَصَحُّ مِنْ حَدِيثِ الأَعْمَشِ عَنْ جَعْفَرِ بْنِ إِيَاسٍ ‏.‏ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ أَبِي بِشْرٍ جَعْفَرِ بْنِ أَبِي وَحْشِيَّةَ عَنْ أَبِي الْمُتَوَكِّلِ عَنْ أَبِي سَعِيدٍ ‏.‏ وَجَعْفَرُ بْنُ إِيَاسٍ هُوَ جَعْفَرُ بْنُ أَبِي وَحْشِيَّةَ ‏.‏\hadithno{2064}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Sa'eed Al Khudri narrated:"Some of the Companions of the Messenger of Allah (S.A.W) came across a tribe of Bedouins that did not entertain them,nor behave hospitality with them. Their leader became ill, and they came to us saying: 'Do you have any medicine?'We said: ' Yes. But you did not entertain us nor have us as guests so we will not do anything until you give us something.' Then they gave sheep for that." He said: 'So a man from us began reciting the Opening of the Book (Surat Al-Fatihah) and he was cured. So when we came to the Messenger of Allah (S.A.W) we mentioned to him, He said: 'How did you know it was Ruqyah?' And he did not mention any prohibition against it,and he said: 'Eat , and assign me a share among you from them (Sheep)}}
\hadithdefcmd{tirmidhi}{2065}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي خُزَامَةَ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رُقًى نَسْتَرْقِيهَا وَدَوَاءً نَتَدَاوَى بِهِ وَتُقَاةً نَتَّقِيهَا هَلْ تَرُدُّ مِنْ قَدَرِ اللَّهِ شَيْئًا قَالَ ‏ "‏ هِيَ مِنْ قَدَرِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ أَبِي خُزَامَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عُيَيْنَةَ كِلْتَا الرِّوَايَتَيْنِ وَقَالَ بَعْضُهُمْ عَنْ أَبِي خُزَامَةَ عَنْ أَبِيهِ وَقَالَ بَعْضُهُمْ عَنِ ابْنِ أَبِي خُزَامَةَ عَنْ أَبِيهِ وَقَالَ بَعْضُهُمْ عَنْ أَبِي خُزَامَةَ وَقَدْ رَوَى غَيْرُ ابْنِ عُيَيْنَةَ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ عَنْ أَبِي خُزَامَةَ عَنْ أَبِيهِ وَهَذَا أَصَحُّ وَلاَ نَعْرِفُ لأَبِي خُزَامَةَ عَنْ أَبِيهِ غَيْرَ هَذَا الْحَدِيثِ ‏.‏\hadithno{2065}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif}\hadithtrans{Abu Khizamah narrated from his father who said:"I asked the Messenger of Allah (S.A.W): 'O Messenger of Allah(S.A.W)! Do you think that the Ruqyah we use, the treatments we use, and what we seek to protect ourselves will contradict anything from Allah's Decree?' He said: 'They are from Allah's Decree}}
\hadithdefcmd{tirmidhi}{2066}{حَدَّثَنَا أَبُو عُبَيْدَةَ، أَحْمَدُ بْنُ عَبْدِ اللَّهِ الْهَمْدَانِيُّ وَهُوَ ابْنُ أَبِي السَّفَرِ وَمَحْمُودُ بْنُ غَيْلاَنَ قَالاَ حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعَجْوَةُ مِنَ الْجَنَّةِ وَفِيهَا شِفَاءٌ مِنَ السُّمِّ وَالْكَمْأَةُ مِنَ الْمَنِّ وَمَاؤُهَا شِفَاءٌ لِلْعَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ سَعِيدِ بْنِ زَيْدٍ وَأَبِي سَعِيدٍ وَجَابِرٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ سَعِيدِ بْنِ عَامِرٍ عَنْ مُحَمَّدِ بْنِ عَمْرٍو ‏.‏\hadithno{2066}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (S.A.W) said:"Al-'Ajwah is from Paradise and it contains a cure for poison. Truffles are a form of manna, and its liquid is a cure for the eye}}
\hadithdefcmd{tirmidhi}{2067}{حَدَّثَنَا أَبُو كُرَيْبٍ، قال حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قال حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قال حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَمْرِو بْنِ حُرَيْثٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْكَمْأَةُ مِنَ الْمَنِّ وَمَاؤُهَا شِفَاءٌ لِلْعَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2067}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'eed bin Zaid narrated that the Prophet (S.A.W) said:"Truffles are a form of manna, and its liquid is a cure for the eye}}
\hadithdefcmd{tirmidhi}{2068}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قال حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قال حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ نَاسًا، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالُوا الْكَمْأَةُ جُدَرِيُّ الأَرْضِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْكَمْأَةُ مِنَ الْمَنِّ وَمَاؤُهَا شِفَاءٌ لِلْعَيْنِ وَالْعَجْوَةُ مِنَ الْجَنَّةِ وَهِيَ شِفَاءٌ مِنَ السُّمِّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2068}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that people among the Companions of the Prophet (S.A.W) would say:"Truffles are the earth's smallpox." So the Messenger of Allah (S.A.W) said: "Truffles are a form of manna, and its liquid is a cure for the eye. Al-'Ajwah is from Paradise, and it contains a cure for poison}}
\hadithdefcmd{tirmidhi}{2069}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قال حَدَّثَنَا مُعَاذٌ، قال حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، قَالَ حُدِّثْتُ أَنَّ أَبَا هُرَيْرَةَ قَالَ أَخَذْتُ ثَلاَثَةَ أَكْمُئٍ أَوْ خَمْسًا أَوْ سَبْعًا فَعَصَرْتُهُنَّ فَجَعَلْتُ مَاءَهُنَّ فِي قَارُورَةٍ فَكَحَلْتُ بِهِ جَارِيَةً لِي فَبَرَأَتْ ‏.‏\hadithno{2069}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Qatadah said:"It was narrated to me that Abu Hurairah said: 'I took three truffles, or five, or seven, and pressed them. Then I put their liquid in a bottle, and I used it on the eyes of a slave girl of mine so she was cured}}
\hadithdefcmd{tirmidhi}{2070}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قال حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قال حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، قَالَ حُدِّثْتُ أَنَّ أَبَا هُرَيْرَةَ قَالَ الشُّونِيزُ دَوَاءٌ مِنْ كُلِّ دَاءٍ إِلاَّ السَّامَ ‏.‏ قَالَ قَتَادَةُ يَأْخُذُ كُلَّ يَوْمٍ إِحْدَى وَعِشْرِينَ حَبَّةً فَيَجْعَلُهُنَّ فِي خِرْقَةٍ فَلْيَنْقَعْهُ فَيَتَسَعَّطُ بِهِ كُلَّ يَوْمٍ فِي مَنْخَرِهِ الأَيْمَنِ قَطْرَتَيْنِ وَفِي الأَيْسَرِ قَطْرَةً وَالثَّانِي فِي الأَيْسَرِ قَطْرَتَيْنِ وَفِي الأَيْمَنِ قَطْرَةً وَالثَّالِثُ فِي الأَيْمَنِ قَطْرَتَيْنِ وَفِي الأَيْسَرِ قَطْرَةً ‏.‏\hadithno{2070}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Qatadah said:"It was narrated to me that Abu Hurairah said:'Ash-Shuniz is a cure for every disease except As-Sam.' Qatadah said: "One takes twenty-one seeds daily, and puts them in a cloth, then infuses (water) and sniffs two drops in his right nostril, and one drop in the left. The second (day) two drops are sniffed in the left, and one drop in the right. The third (day) two drops in the right and one drop in the left}}
\hadithdefcmd{tirmidhi}{2071}{حَدَّثَنَا قُتَيْبَةُ، قال حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2071}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Masud Al-Ansari narrated:"The Messenger of Allah (S.A.W) prohibited the price of a dog,the earnings of a fornicator (from fornication), and the payment made to the fortune-teller}}
\hadithdefcmd{tirmidhi}{2072}{حَدَّثَنَا مُحَمَّدُ بْنُ مَدُّويَهْ، قال حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عِيسَى، أَخِيهِ قَالَ دَخَلْتُ عَلَى عَبْدِ اللَّهِ بْنِ عُكَيْمٍ أَبِي مَعْبَدٍ الْجُهَنِيِّ أَعُودُهُ وَبِهِ حُمْرَةٌ فَقُلْنَا أَلاَ تُعَلِّقُ شَيْئًا قَالَ الْمَوْتُ أَقْرَبُ مِنْ ذَلِكَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ تَعَلَّقَ شَيْئًا وُكِلَ إِلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى ‏.‏ وَعَبْدُ اللَّهِ بْنُ عُكَيْمٍ لَمْ يَسْمَعْ مِنَ النَّبِيِّ صلى الله عليه وسلم وَكَانَ فِي زَمَنِ النَّبِيِّ صلى الله عليه وسلم يَقُولُ كَتَبَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قال حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ أَبِي لَيْلَى، نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُقْبَةَ بْنِ عَامِرٍ، ‏.‏\hadithno{2072}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Eisa Ibn 'Abdur-Raman bin Abi Laila said:"I entered upon 'Abdullah bin 'Ukaim Abu Mabad Al-Juhani to visit him, while he had Humrah. I said:'Why don't you hang something?' He said: 'Death is better than that. The Prophet (S.A.W) said: "Whoever hangs something, he is entrusted to it." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2073}{حَدَّثَنَا هَنَّادٌ، قال حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى فَوْرٌ مِنَ النَّارِ فَأَبْرِدُوهَا بِالْمَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ وَابْنِ عُمَرَ وَامْرَأَةِ الزُّبَيْرِ وَعَائِشَةَ وَابْنِ عَبَّاسٍ ‏.‏\hadithno{2073}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Rafi' bin Khadij narrated that the Prophet (S.A.W) said:"Fever is from the agitation of the Fire, so cool it with water}}
\hadithdefcmd{tirmidhi}{2074}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، قال حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَأَبْرِدُوهَا بِالْمَاءِ ‏"‏ ‏.‏ حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ، قال حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي حَدِيثِ أَسْمَاءَ كَلاَمٌ أَكْثَرُ مِنْ هَذَا وَكِلاَ الْحَدِيثَيْنِ صَحِيحٌ ‏.‏\hadithno{2074}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated that the Messenger of Allah (S.A.W) said:"Fever is from the heat of the Hell, so cool it with water." Another chain reports similar narration}}
\hadithdefcmd{tirmidhi}{2075}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قال حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، قال حَدَّثَنَا إِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ بْنِ أَبِي حَبِيبَةَ، عَنْ دَاوُدَ بْنِ حُصَيْنٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُعَلِّمُهُمْ مِنَ الْحُمَّى وَمِنَ الأَوْجَاعِ كُلِّهَا أَنْ يَقُولَ ‏"‏ بِسْمِ اللَّهِ الْكَبِيرِ أَعُوذُ بِاللَّهِ الْعَظِيمِ مِنْ شَرِّ كُلِّ عِرْقٍ نَعَّارٍ وَمِنْ شَرِّ حَرِّ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ إِبْرَاهِيمَ بْنِ إِسْمَاعِيلَ بْنِ أَبِي حَبِيبَةَ ‏.‏ وَإِبْرَاهِيمُ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏ وَيُرْوَى ‏"‏ عِرْقٍ يَعَّارٍ ‏"‏ ‏.‏\hadithno{2075}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Abbas narrated:"For fever, and all pains, the Prophet (S.A.W) would teach them to say: Bismillahil-Kabir; a'udhu billahil-'Azimi min sharri kulli 'irqin na'arin, wa min sharri harrin-nar. (In the name of Allah the Great, I seek refuge with Allah the Magnificent from the evil of every gushing vein, and from the evil of the heat of the Fire)}}
\hadithdefcmd{tirmidhi}{2076}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قال حَدَّثَنَا يَحْيَى بْنُ إِسْحَاقَ، قال حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ ابْنَةِ وَهْبٍ، وَهِيَ جُدَامَةُ - قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَرَدْتُ أَنْ أَنْهَى عَنِ الْغِيَالِ فَإِذَا فَارِسُ وَالرُّومُ يَفْعَلُونَ وَلاَ يَقْتُلُونَ أَوْلاَدَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ مَالِكٌ عَنْ أَبِي الأَسْوَدِ عَنْ عُرْوَةَ عَنْ عَائِشَةَ عَنْ جُدَامَةَ بِنْتِ وَهْبٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ مَالِكٌ وَالْغِيَالُ أَنْ يَطَأَ الرَّجُلُ امْرَأَتَهُ وَهِيَ تُرْضِعُ ‏.‏\hadithno{2076}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated from Wahb's daughter - and she is Judamah - who said:"I heard the Messenger of Allah (S.A.W) saying: 'I wanted to prohibit Al-Ghilah, but the Persians and Romans did it, and they did not kill their children}}
\hadithdefcmd{tirmidhi}{2077}{حَدَّثَنَا عِيسَى بْنُ أَحْمَدَ، قال حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنْ جُدَامَةَ بِنْتِ وَهْبٍ الأَسَدِيَّةِ، أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ أَنْهَى عَنِ الْغِيلَةِ حَتَّى ذُكِّرْتُ أَنَّ الرُّومَ وَفَارِسَ يَصْنَعُونَ ذَلِكَ فَلاَ يَضُرُّ أَوْلاَدَهُمْ ‏"‏ ‏.‏ قَالَ مَالِكٌ وَالْغِيلَةُ أَنْ يَمَسَّ الرَّجُلُ امْرَأَتَهُ وَهِيَ تُرْضِعُ ‏.‏ قَالَ عِيسَى بْنُ أَحْمَدَ وَحَدَّثَنَا إِسْحَاقُ بْنُ عِيسَى حَدَّثَنِي مَالِكٌ عَنْ أَبِي الأَسْوَدِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{2077}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated from Judamah bint Wahb Al-Asadiyyah that she heard the Messenger of Allah (S.A.W) saying:"I intended to prohibit Al-Ghilah until I remembered that the Persians and Romans do that, without any harm to their children}}
\hadithdefcmd{tirmidhi}{2078}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي عَبْدِ اللَّهِ، عَنْ زَيْدِ بْنِ أَرْقَمَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَنْعَتُ الزَّيْتَ وَالْوَرْسَ مِنْ ذَاتِ الْجَنْبِ ‏.‏ قَالَ قَتَادَةُ وَيَلُدُّهُ مِنَ الْجَانِبِ الَّذِي يَشْتَكِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو عَبْدِ اللَّهِ اسْمُهُ مَيْمُونٌ هُوَ شَيْخٌ بَصْرِيٌّ ‏.‏\hadithno{2078}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Qatadah narrated from Abu 'Abdullah that Zaid bin Arqam said:"The Prophet (S.A.W) would acclaim oil and Wars for (the treatment of) pleurisy." Qatadah said: "And it is put in the mouth on the side which he is suffering}}
\hadithdefcmd{tirmidhi}{2079}{حَدَّثَنَا رَجَاءُ بْنُ مُحَمَّدٍ الْعُذْرِيُّ الْبَصْرِيُّ، قال حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدِ بْنِ أَبِي رَزِينٍ، قال حَدَّثَنَا شُعْبَةُ، عَنْ خَالِدٍ الْحَذَّاءِ، حَدَّثَنَا مَيْمُونٌ أَبُو عَبْدِ اللَّهِ، قَالَ سَمِعْتُ زَيْدَ بْنَ أَرْقَمَ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَتَدَاوَى مِنْ ذَاتِ الْجَنْبِ بِالْقُسْطِ الْبَحْرِيِّ وَالزَّيْتِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مَيْمُونٍ عَنْ زَيْدِ بْنِ أَرْقَمَ ‏.‏ وَقَدْ رَوَى عَنْ مَيْمُونٍ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ هَذَا الْحَدِيثَ ‏.‏ وَذَاتُ الْجَنْبِ السُّلُّ ‏.‏\hadithno{2079}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Maimun Abu' Abdullah said:"I heard Zaid bin Arqam say: 'The Messenger of Allah (S.A.W) ordered us to use Qust Al-Bahri and oil to treat Pleurisy}}
\hadithdefcmd{tirmidhi}{2080}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، قال حَدَّثَنَا مَعْنٌ، قال حَدَّثَنَا مَالِكٌ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ كَعْبٍ السُّلَمِيِّ، أَنَّ نَافِعَ بْنَ جُبَيْرِ بْنِ مُطْعِمٍ، أَخْبَرَهُ عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِي، أَنَّهُ قَالَ أَتَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَبِي وَجَعٌ قَدْ كَانَ يُهْلِكُنِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ امْسَحْ بِيَمِينِكَ سَبْعَ مَرَّاتٍ وَقُلْ أَعُوذُ بِعِزَّةِ اللَّهِ وَقُوَّتِهِ مِنْ شَرِّ مَا أَجِدُ ‏"‏ ‏.‏ قَالَ فَفَعَلْتُ فَأَذْهَبَ اللَّهُ مَا كَانَ بِي فَلَمْ أَزَلْ آمُرُ بِهِ أَهْلِي وَغَيْرَهُمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2080}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Uthman bin Abi Al-'As narrated:"The Messenger of Allah (S.A.W) came to me while I had a pain that almost ruined me. So,the Messenger of Allah (S.A.W) said: 'Rub it with your right hand seven times and say A`udhu bi `Izzatillah Wa Qudratihi wa Sultanihi min sharri ma ajid." ("I seek refuge in Allah's might, power, an authority, from the evil of what I suffer.)" He said: "So I did it, and Allah removed what I had, and I never ceased telling my family and others to do it}}
\hadithdefcmd{tirmidhi}{2081}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قال حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنِي عُتْبَةُ بْنُ عَبْدِ اللَّهِ، عَنْ أَسْمَاءَ بِنْتِ عُمَيْسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَأَلَهَا ‏"‏ بِمَ تَسْتَمْشِينَ ‏"‏ ‏.‏ قَالَتْ بِالشُّبْرُمِ ‏.‏ قَالَ ‏"‏ حَارٌّ جَارٌّ ‏"‏ ‏.‏ قَالَتْ ثُمَّ اسْتَمْشَيْتُ بِالسَّنَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ أَنَّ شَيْئًا كَانَ فِيهِ شِفَاءٌ مِنَ الْمَوْتِ لَكَانَ فِي السَّنَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ يَعْنِي دَوَاءَ الْمَشْىِّ ‏.‏\hadithno{2081}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Asma' bint 'Umais narrated that the Messenger of Allah (S.A.W) asked her what they used as a laxative. She said:"Shubrum" He said: "It is hot and too strong." She said:"Then I used Senna as a laxative." So the Prophet (S.A.W) said: "If there was anything that would have a cure for death in it, then it would have been Senna}}
\hadithdefcmd{tirmidhi}{2082}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ،قال حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قال حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ أَخِي اسْتُطْلِقَ بَطْنُهُ ‏.‏ فَقَالَ ‏"‏ اسْقِهِ عَسَلاً ‏"‏ ‏.‏ فَسَقَاهُ ثُمَّ جَاءَ فَقَالَ يَا رَسُولَ اللَّهِ قَدْ سَقَيْتُهُ عَسَلاً فَلَمْ يَزِدْهُ إِلاَّ اسْتِطْلاَقًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْقِهِ عَسَلاً ‏"‏ ‏.‏ فَسَقَاهُ ثُمَّ جَاءَهُ فَقَالَ يَا رَسُولَ اللَّهِ قَدْ سَقَيْتُهُ عَسَلاً فَلَمْ يَزِدْهُ إِلاَّ اسْتِطْلاَقًا ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَدَقَ اللَّهُ وَكَذَبَ بَطْنُ أَخِيكَ, اسْقِهِ عَسَلاً ‏"‏ ‏.‏ فَسَقَاهُ عَسَلاً فَبَرَأَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2082}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Sa'eed said:"A man came to the Prophet (S.A.W) and said: 'My brother is suffering from loose bowels.' He said: 'Let him drink Honey.' So he drank it. Then he came and said: O Messenger of Allah (S.A.W)! He has drunk honey, but it has only made him more worse.' So the Messenger of Allah (S.A.W) said: ' Let him drink honey.'" He said: "So he drank it. Then he came and said: 'O Messenger of Allah (S.A.W)! I gave him some more to drink, but it has only made him more worse.'" He said: "The Messenger of Allah (S.A.W) said: 'Allah has told the truth,and your brother's stomach has lied. Give him honey to drink'. So he gave him some more honey to drink and he was cured}}
\hadithdefcmd{tirmidhi}{2083}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قال حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قال حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ أَبِي خَالِدٍ، قَالَ سَمِعْتُ الْمِنْهَالَ بْنَ عَمْرٍو، يُحَدِّثُ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَا مِنْ عَبْدٍ مُسْلِمٍ يَعُودُ مَرِيضًا لَمْ يَحْضُرْ أَجَلُهُ فَيَقُولُ سَبْعَ مَرَّاتٍ أَسْأَلُ اللَّهَ الْعَظِيمَ رَبَّ الْعَرْشِ الْعَظِيمِ أَنْ يَشْفِيَكَ إِلاَّ عُوفِيَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْمِنْهَالِ بْنِ عَمْرٍو ‏.‏\hadithno{2083}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Abbas narrated that the Prophet (S.A.W) said:"There is no Muslim worshiper who visits one who is ill - other than at the time of death - and he says seven times: As'alullah Al-'Azeem Rabbal 'Arshil 'Azeem an yashfik ('I ask Allah the Magnificent, Lord of the Magnificent Throne to cure you') except when he will be cured}}
\hadithdefcmd{tirmidhi}{2084}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الأَشْقَرُ الرِّبَاطِيُّ، قال حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، قال حَدَّثَنَا مَرْزُوقٌ أَبُو عَبْدِ اللَّهِ الشَّامِيُّ، قال حَدَّثَنَا سَعِيدٌ، رَجُلٌ مِنْ أَهْلِ الشَّامِ أَخْبَرَنَا ثَوْبَانُ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَصَابَ أَحَدَكُمُ الْحُمَّى فَإِنَّ الْحُمَّى قِطْعَةٌ مِنَ النَّارِ فَلْيُطْفِئْهَا عَنْهُ بِالْمَاءِ فَلْيَسْتَنْقِعْ نَهْرًا جَارِيًا لِيَسْتَقْبِلَ جَرْيَةَ الْمَاءِ فَيَقُولُ بِسْمِ اللَّهِ اللَّهُمَّ اشْفِ عَبْدَكَ وَصَدِّقْ رَسُولَكَ بَعْدَ صَلاَةِ الصُّبْحِ قَبْلَ طُلُوعِ الشَّمْسِ فَلْيَغْتَمِسْ فِيهِ ثَلاَثَ غَمَسَاتٍ ثَلاَثَةَ أَيَّامٍ فَإِنْ لَمْ يَبْرَأْ فِي ثَلاَثٍ فَخَمْسٌ وَإِنْ لَمْ يَبْرَأْ فِي خَمْسٍ فَسَبْعٌ فَإِنْ لَمْ يَبْرَأْ فِي سَبْعٍ فَتِسْعٌ فَإِنَّهَا لاَ تَكَادُ تُجَاوِزُ تِسْعًا بِإِذْنِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2084}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Thawban narrated that the Prophet (S.A.W) said:"When one of you suffers from fever - and indeed fever is a piece of the Fire - let him extinguish it with water. Let him stand in a flowing river facing the direction of it and say: Allahummashfi 'abdaka wa saddik Rasulak ('In the name off Allah. O Allah! Cure your slave and testify to Your Messenger.)' Doing so after Salat As-Subh(Fajr) and before the rising of the sun. Let him submerse himself in it three times, for three days. If he is not cured in three, then five. If he is not cured in five, then seven. If he is not cured in seven, then nine. For indeed it will not remain after nine, with the permission of Allah}}
\hadithdefcmd{tirmidhi}{2085}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، قال حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي حَازِمٍ، قَالَ سُئِلَ سَهْلُ بْنُ سَعْدٍ وَأَنَا أَسْمَعُ، بِأَىِّ شَيْءٍ دُووِيَ جُرْحُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ مَا بَقِيَ أَحَدٌ أَعْلَمُ بِهِ مِنِّي كَانَ عَلِيٌّ يَأْتِي بِالْمَاءِ فِي تُرْسِهِ وَفَاطِمَةُ تَغْسِلُ عَنْهُ الدَّمَ وَأُحْرِقَ لَهُ حَصِيرٌ فَحُشِيَ بِهِ جُرْحُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2085}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hazim said:"While I was listening, Sahl bin Sa'd was asked: 'What were the wounds of the Messenger of Allah (S.A.W) treated with?' He said: 'None is alive who is more knowledgeable of it than I. 'Ali would come with water in his shield, and Fatimah would use it to wash his blood off,and a mat was burnt for him and his wounds were filled with it(its ashes)}}
\hadithdefcmd{tirmidhi}{2086}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَخْبَرَنَا الْوَلِيدُ بْنُ مُحَمَّدٍ الْمُوَقَّرِيُّ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا مَثَلُ الْمَرِيضِ إِذَا بَرَأَ وَصَحَّ كَالْبَرْدَةِ تَقَعُ مِنَ السَّمَاءِ فِي صَفَائِهَا وَلَوْنِهَا ‏"‏ ‏.‏\hadithno{2086}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (S.A.W) said:"The parable of the ill when he is cured and becomes healthy is that of hail that falls from the heavens in its purity and its color}}
\hadithdefcmd{tirmidhi}{2087}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الأَشَجُّ، قال حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ السَّكُونِيُّ، عَنْ مُوسَى بْنِ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلْتُمْ عَلَى الْمَرِيضِ فَنَفِّسُوا لَهُ فِي أَجَلِهِ فَإِنَّ ذَلِكَ لاَ يَرُدُّ شَيْئًا وَيُطَيِّبُ نَفْسَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2087}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Messenger of Allah (S.A.W) said:"When one of you visits the ill, then reassure him regarding his lifespan. Indeed that will not repel anything, but it will comfort his soul}}
\hadithdefcmd{tirmidhi}{2088}{حَدَّثَنَا هَنَّادٌ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ إِسْمَاعِيلَ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي صَالِحٍ الأَشْعَرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم عَادَ رَجُلاً مِنْ وَعَكٍ كَانَ بِهِ فَقَالَ ‏ "‏ أَبْشِرْ فَإِنَّ اللَّهَ يَقُولُ هِيَ نَارِي أُسَلِّطُهَا عَلَى عَبْدِي الْمُذْنِبِ لِتَكُونَ حَظَّهُ مِنَ النَّارِ ‏"‏ ‏.‏ حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ قَالَ أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ عَنْ سُفْيَانَ الثَّوْرِيِّ عَنْ هِشَامِ بْنِ حَسَّانَ عَنِ الْحَسَنِ قَالَ كَانُوا يَرْتَجُونَ الْحُمَّى لَيْلَةً كَفَّارَةً لِمَا نَقَصَ مِنَ الذُّنُوبِ ‏.‏ تَمَّ كِتَابُ الطِّبِّ وَيَلِيهِ كِتَابُ الْفَرَائِضِ\hadithno{2088}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Prophet(S.A.W) visited a man who was ill, so he said:"Cheer up, for indeed Allah said: 'It is My Fire which I impose upon My sinning slave as his portion of the Fire." (Hasan) Al-Hasan said: "They would hope that the fever that occurred at night would atone for any deficiency caused by sins}}
\hadithdefcmd{tirmidhi}{2089}{\hadithno{2089}\hadithtrans{}}
